Changelog
---------


2.0.0b2 (2016-10-31)
^^^^^^^^^^^^^^^^^^^^

- documentation update for indigo
- update requirements
- move marv-robotics distribtion top-level


2.0.0b1 (2016-10-07)
^^^^^^^^^^^^^^^^^^^^
- initial release

